from PyObjCTools.TestSupport import TestCase, min_os_level
import CoreML


class TestMLDictionaryFeatureProvider(TestCase):
    @min_os_level("10.13")
    def testMethods10_13(self):
        self.assertArgIsOut(
            CoreML.MLDictionaryFeatureProvider.initWithDictionary_error_, 1
        )



import objc

from PyObjCTools.TestSupport import TestCase, min_sdk_level
import CoreML  # noqa: F401


class TestMLDictionaryFeatureProvider(TestCase):
    @min_sdk_level("10.13")
    def testProtocols(self):
        objc.protocolNamed("MLFeatureProvider")



import objc

from PyObjCTools.TestSupport import TestCase, min_sdk_level
import CoreML


class TestMLCustomModelHelper(CoreML.NSObject):
    def initWithModelDescription_parameterDictionary_error_(self, a, b, c):
        return 1

    def predictionFromFeatures_options_error_(self, a, b, c):
        return 1

    def predictionsFromBatch_options_error_(self, a, b, c):
        return 1


class TestMLCustomModel(TestCase):
    @min_sdk_level("10.14")
    def testProtocols(self):
        objc.protocolNamed("MLCustomModel")

    def testMethods(self):
        self.assertArgHasType(
            TestMLCustomModelHelper.initWithModelDescription_parameterDictionary_error_,
            2,
            b"o^@",
        )
        self.assertArgHasType(
            TestMLCustomModelHelper.predictionFromFeatures_options_error_, 2, b"o^@"
        )
        self.assertArgHasType(
            TestMLCustomModelHelper.predictionsFromBatch_options_error_, 2, b"o^@"
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import CoreML


class TestMLUpdateProgressHandlers(TestCase):
    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertArgIsBlock(
            CoreML.MLUpdateProgressHandlers.initForEvents_progressHandler_completionHandler_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            CoreML.MLUpdateProgressHandlers.initForEvents_progressHandler_completionHandler_,
            2,
            b"v@",
        )



from PyObjCTools.TestSupport import TestCase
import CoreML


class TestMLTask(TestCase):
    def test_constants(self):
        self.assertEqual(CoreML.MLTaskStateSuspended, 1)
        self.assertEqual(CoreML.MLTaskStateRunning, 2)
        self.assertEqual(CoreML.MLTaskStateCancelling, 3)
        self.assertEqual(CoreML.MLTaskStateCompleted, 4)
        self.assertEqual(CoreML.MLTaskStateFailed, 5)
